a:28:{s:9:"ins_email";i:1;s:9:"rem_email";i:1;s:16:"editdetail_email";i:1;s:12:"backup_email";i:1;s:22:"disable_template_email";i:0;s:21:"disable_restore_email";i:0;s:30:"disable_restore_template_email";i:0;s:19:"disable_clone_email";i:0;s:21:"disable_staging_email";i:0;s:20:"disable_import_email";i:0;s:25:"disable_all_notify_update";i:0;s:19:"email_password_user";i:0;s:8:"timezone";i:0;s:5:"email";s:27:"tuhinahmedapple94@gmail.com";s:10:"pfxapi_key";i:0;s:11:"eula_accept";N;s:18:"custom_demo_domain";N;s:20:"custom_demo_launcher";N;s:12:"demo_expires";N;s:11:"wp_fp_modal";i:-1;s:11:"color_theme";a:4:{s:18:"left_panel_cathead";i:0;s:21:"left_panel_scriptname";i:0;s:13:"left_panel_bg";i:0;s:24:"left_panel_cathead_hover";i:0;}s:18:"user_defined_color";i:0;s:19:"disable_suggestions";i:0;s:21:"disable_softai_notice";i:0;s:14:"arrange_domain";i:0;s:23:"default_backup_location";i:0;s:13:"off_backup_au";i:0;s:11:"saved_email";i:1;}